@@ -78,6 +78,7 @@ def add_pre_prefix_one(symbol):
     else:
         return 'BJ' + symbol
 
+
 # 添加后缀
 def add_after_prefix_one(symbol):
     symbol_simple = symbol[0:6]
@@ -117,8 +118,7 @@ def exclude_st_symbol(real_time_quotes_now_df):
 # 排除带星的ST 容易退市
 def exclude_star_st_symbol(df):
     exclude_st_symbol_list = list(
-        df.loc[(df['name'].str.contains('\*'))
-               | (df['name'].str.contains('退'))]['symbol'])
+        df.loc[(df['name'].str.contains(r'\*')) | (df['name'].str.contains('退'))]['symbol'])
     return df.loc[
         ~(df['symbol'].isin(
             exclude_st_symbol_list))]
