@@ -188,3 +188,8 @@ STOCK_QFQ_YEAR = 'stock_qfq_year'
 MAIN_LINE_LIST = 'main_line_list'
 # 主线详情
 MAIN_LINE_DETAIL = 'main_line_detail'
+
+# 整体选择表
+STRATEGY_TOTAL_CHOOSE_PARAM = 'strategy_total_choose_param'
+# k 线参数表
+STRATEGY_K_LINE_PARAM = 'strategy_k_line_param'
